import React, { useState, useRef, useEffect, useMemo } from "react";
import {
    CreateBase,
    useTranslate,
    TextInput,
    NumberInput,
    BooleanInput,
    DateInput,
    SaveButton,
    SelectInput,
    ReferenceInput,
    ReferenceArrayInput,
    AutocompleteInput,
    Toolbar,
    required,
    useDataProvider,
    useNotify,
    Form,
    useCreateController,
    SelectArrayInput,
} from 'react-admin';
import {
    Dialog,
    DialogActions,
    DialogContent,
    DialogTitle,
    Stack,
    Grid,
    Box,
} from '@mui/material';
import DialogCloseButton from "../../components/DialogCloseButton";
import StatusSelectInput from "../../components/StatusSelectInput";
import MemoInput from "../../components/MemoInput";
import DictionarySelect from "../../components/DictionarySelect";

const BasStationCreate = (props) => {
    const { open, setOpen } = props;

    const translate = useTranslate();
    const notify = useNotify();

    const handleClose = (event, reason) => {
        if (reason !== "backdropClick") {
            setOpen(false);
        }
    };

    const handleSuccess = async (data) => {
        setOpen(false);
        notify('common.response.success');
    };

    const handleError = async (error) => {
        notify(error.message || 'common.response.fail', { type: 'error', messageArgs: { _: error.message } });
    };

    return (
        <>
            <CreateBase
                record={{}}
                transform={(data) => {
                    return data;
                }}
                mutationOptions={{ onSuccess: handleSuccess, onError: handleError }}
            >
                <Dialog
                    open={open}
                    onClose={handleClose}
                    aria-labelledby="form-dialog-title"
                    fullWidth
                    disableRestoreFocus
                    maxWidth="md"   // 'xs' | 'sm' | 'md' | 'lg' | 'xl'
                >
                    <Form>
                        <DialogTitle id="form-dialog-title" sx={{
                            position: 'sticky',
                            top: 0,
                            backgroundColor: 'background.paper',
                            zIndex: 1000
                        }}
                        >
                            {translate('create.title')}
                            <Box sx={{ position: 'absolute', top: 8, right: 8, zIndex: 1001 }}>
                                <DialogCloseButton onClose={handleClose} />
                            </Box>
                        </DialogTitle>
                        <DialogContent sx={{ mt: 2 }}>
                            <Grid container rowSpacing={2} columnSpacing={2}>
                                <Grid item xs={6} display="flex" gap={1}>
                                    <TextInput
                                        label="table.field.basStation.stationName"
                                        source="stationName"
                                        parse={v => v}
                                        autoFocus
                                    />
                                </Grid>
                                <Grid item xs={6} display="flex" gap={1}>
                                    <SelectInput
                                        label="table.field.basStation.inAble"
                                        source="inAble"
                                        choices={[
                                            { id: 0, name: '否' },
                                            { id: 1, name: '是' },
                                        ]}
                                    />
                                </Grid>
                                <Grid item xs={6} display="flex" gap={1}>
                                    <SelectInput
                                        label="table.field.basStation.outAble"
                                        source="outAble"
                                        choices={[
                                            { id: 0, name: '否' },
                                            { id: 1, name: '是' },
                                        ]}
                                    />
                                </Grid>
                                <Grid item xs={6} display="flex" gap={1}>
                                    <DictionarySelect
                                        label={translate("table.field.basStation.useStatus")}
                                        name="useStatus"
                                        size="small"
                                        validate={[required()]}
                                        dictTypeCode="sys_sta_use_stas"
                                    />
                                </Grid>
                                <Grid item xs={6} display="flex" gap={1}>
                                    <ReferenceInput source="area" reference="warehouseAreas">
                                        <SelectInput 
                                            label="table.field.basStation.area"
                                            optionText="name"
                                            optionValue="id"
                                            fullWidth  
                                            validate={[required()]}     
                                        />
                                    </ReferenceInput>
                                </Grid>
                                <Grid item xs={6} display="flex" gap={1}>
                                <SelectInput
                                    label="table.field.basStation.isCrossZone"
                                    source="isCrossZone"
                                    choices={[
                                        { id: 0, name: '否' },
                                        { id: 1, name: '是' },
                                    ]}
                                    validate={[required()]}
                            />
                                </Grid>
                                <Grid item xs={6} display="flex" gap={1}>
                                <ReferenceArrayInput source="areaIds" reference="warehouseAreas">
                                <SelectArrayInput 
                                    label="table.field.basStation.crossZoneArea"
                                    optionText="name"
                                    optionValue="id"
                                    fullWidth       
                                />
                            </ReferenceArrayInput>
                                </Grid>
                                <Grid item xs={6} display="flex" gap={1}>
                                <SelectInput
                                    label="table.field.basStation.isWcs"
                                    source="isWcs"
                                    choices={[
                                        { id: 0, name: '否' },
                                        { id: 1, name: '是' },
                                    ]}
                                    validate={[required()]}
                            />
                                </Grid>                                
                                <Grid item xs={6} display="flex" gap={1}>
                                <DictionarySelect
                                    label={translate("table.field.basStation.containerType")}
                                    name="containerType"
                                    size="small"
                                    validate={[required()]}
                                    dictTypeCode="sys_container_type"
                                />
                                </Grid>                                
                                <Grid item xs={6} display="flex" gap={1}>
                                <SelectInput
                                    label="table.field.basStation.autoTransfer"
                                    source="autoTransfer"
                                    choices={[
                                        { id: 0, name: '否' },
                                        { id: 1, name: '是' },
                                    ]}
                            />
                                </Grid>

                                <Grid item xs={12} display="flex" gap={1}>
                                    <Stack direction="column" spacing={1} width={'100%'}>
                                        <MemoInput />
                                    </Stack>
                                </Grid>
                            </Grid>
                        </DialogContent>
                        <DialogActions sx={{ position: 'sticky', bottom: 0, backgroundColor: 'background.paper', zIndex: 1000 }}>
                            <Toolbar sx={{ width: '100%', justifyContent: 'space-between' }}  >
                                <SaveButton />
                            </Toolbar>
                        </DialogActions>
                    </Form>
                </Dialog>
            </CreateBase>
        </>
    )
}

export default BasStationCreate;
